==> zpt-0.34.0.tgz: package/test/js/app/index.js <==
QUnit.testSuites([
    { name: "expressions Test Suite", path: "./expressions.html" },
    { name: "statements Test Suite", path: "./statements.html" },
    { name: "omit-tag tag Test Suite", path: "./omit-tag.html" },
    { name: "vars scope Test Suite", path: "./scope.html" },
	{ name: "loops Test Suite", path: "./loops.html" },
	{ name: "nested loops Test Suite", path: "./nestedLoops.html" },
	{ name: "macros Test Suite", path: "./macros.html" },
    { name: "external macros Test Suite", path: "./externalMacros.html" },
    { name: "jquery expressions Test Suite", path: "./jquery.html" },
	{ name: "on-error tag Test Suite", path: "./on-error.html" },
    { name: "jquery plugin Test Suite", path: "./jqueryPlugin.html" },
    { name: "formatters Test Suite", path: "./format.html" },
    { name: "rerun simple Test Suite", path: "./rerunSimple.html" },
    { name: "rerun macro Test Suite", path: "./rerunMacros.html" },
    { name: "i18n Test Suite", path: "./i18n.html" },
    { name: "i18n async Test Suite", path: "./i18nAsync.html" },
    { name: "i18n async auto Test Suite", path: "./i18nAsyncAuto.html" },
    { name: "custom expressions Test Suite", path: "./customExpressions.html" },
    { name: "errors Test Suite", path: "./errors.html" },
    { name: "multiroot Test Suite", path: "./multiroot.html" },
    { name: "original tags Test Suite", path: "./original.html" },
    { name: "recursive macros Test Suite", path: "./recursiveMacros.html" },
    { name: "mixed macros Test Suite", path: "./mixedMacros.html" },
    { name: "standalone Test Suite", path: "./standalone.html" },
    { name: "external macros with absolute URLs Test Suite", path: "./moreTest/externalMacros-absoluteURLs.html" },
    { name: "external macros with prefix URLs Test Suite", path: "./moreTest/externalMacros-prefixURLs.html" },
    { name: "single root Test Suite", path: "./singleRoot.html" },
    { name: "dictionary extension Test Suite", path: "./dictionaryExtension.html" },
    { name: "Folder dictionary Test Suite", path: "./folderDictionaries.html" },
    { name: "Folder dictionary level 2 Test Suite", path: "./moreTest/folderDictionaries2.html" }
]);

==> zpt-0.36.0.tgz: package/test/js/app/index.js <==
QUnit.testSuites([
    { name: "expressions Test Suite", path: "./expressions.html" },
    { name: "statements Test Suite", path: "./statements.html" },
    { name: "omit-tag tag Test Suite", path: "./omit-tag.html" },
    { name: "vars scope Test Suite", path: "./scope.html" },
	{ name: "loops Test Suite", path: "./loops.html" },
	{ name: "nested loops Test Suite", path: "./nestedLoops.html" },
	{ name: "macros Test Suite", path: "./macros.html" },
    { name: "external macros Test Suite", path: "./externalMacros.html" },
    { name: "jquery expressions Test Suite", path: "./jquery.html" },
	{ name: "on-error tag Test Suite", path: "./on-error.html" },
    { name: "jquery plugin Test Suite", path: "./jqueryPlugin.html" },
    { name: "formatters Test Suite", path: "./format.html" },
    { name: "rerun simple Test Suite", path: "./rerunSimple.html" },
    { name: "rerun macro Test Suite", path: "./rerunMacros.html" },
    { name: "i18n Test Suite", path: "./i18n.html" },
    { name: "i18n async Test Suite", path: "./i18nAsync.html" },
    { name: "i18n async auto Test Suite", path: "./i18nAsyncAuto.html" },
    { name: "custom expressions Test Suite", path: "./customExpressions.html" },
    { name: "errors Test Suite", path: "./errors.html" },
    { name: "multiroot Test Suite", path: "./multiroot.html" },
    { name: "original tags Test Suite", path: "./original.html" },
    { name: "recursive macros Test Suite", path: "./recursiveMacros.html" },
    { name: "mixed macros Test Suite", path: "./mixedMacros.html" },
    { name: "standalone Test Suite", path: "./standalone.html" },
    { name: "external macros with absolute URLs Test Suite", path: "./moreTest/externalMacros-absoluteURLs.html" },
    { name: "external macros with prefix URLs Test Suite", path: "./moreTest/externalMacros-prefixURLs.html" },
    { name: "single root Test Suite", path: "./singleRoot.html" },
    { name: "dictionary extension Test Suite", path: "./dictionaryExtension.html" },
    { name: "Folder dictionary Test Suite", path: "./folderDictionaries.html" },
    { name: "Folder dictionary level 2 Test Suite", path: "./moreTest/folderDictionaries2.html" },
    { name: "declare root Test Suite", path: "./declare.html" },
    { name: "update Test Suite", path: "./update.html" }
]);
